Index: chrome/browser/tab_restore_uitest.cc |
=================================================================== |
--- chrome/browser/tab_restore_uitest.cc (revision 88158) |
+++ chrome/browser/tab_restore_uitest.cc (working copy) |
@@ -602,7 +602,7 @@ |
EXPECT_TRUE(url == url2_); |
} |
// Restore tab with special URL chrome://credits/ and make sure the page loads |
// properly after restore. See http://crbug.com/31905. |
TEST_F(TabRestoreUITest, RestoreTabWithSpecialURL) { |
scoped_refptr<BrowserProxy> browser(automation()->GetBrowserWindow(0)); |
@@ -610,7 +610,7 @@ |
CheckActiveWindow(browser.get()); |
// Navigate new tab to a special URL. |
- const GURL special_url(chrome::kChromeUICreditsURL); |
+ const GURL special_url(chrome::kAboutCreditsURL); |
ASSERT_TRUE(browser->AppendTab(special_url)); |
scoped_refptr<TabProxy> tab(browser->GetActiveTab()); |
ASSERT_TRUE(tab.get()); |
@@ -643,7 +643,7 @@ |
CheckActiveWindow(browser.get()); |
// Navigate new tab to a special URL. |
- const GURL special_url(chrome::kChromeUICreditsURL); |
+ const GURL special_url(chrome::kAboutCreditsURL); |
ASSERT_TRUE(browser->AppendTab(special_url)); |
scoped_refptr<TabProxy> tab(browser->GetActiveTab()); |
ASSERT_TRUE(tab.get()); |
@@ -602,7 +602,7 @@ |
EXPECT_TRUE(url == url2_); |
} |
-// Restore tab with special URL chrome://credits/ and make sure the page loads |
+// Restore tab with special URL about:credits and make sure the page loads |
// properly after restore. See http://crbug.com/31905. |
TEST_F(TabRestoreUITest, RestoreTabWithSpecialURL) { |